@@ -1,13 +1,15 @@
 import json
 import logging
-from ipware.ip import get_real_ip
+from typing import Optional
+
+from ipware.ip import get_real_ip  # pytype: disable=import-error
 from rest_framework.request import Request
 
 
 logger = logging.getLogger(__name__)
 
 
-def log_event(name: str, request: Request or None = None, data: dict or None = None, ip: str = ''):
+def log_event(name: str, request: Optional[Request] = None, data: Optional[dict] = None, ip: str = ''):
     """
     Logs consistent event for easy parsing/analysis.
     Format: EVENT_<UPPERCASE_NAME>: <JSON object>
